@@ -28,6 +28,9 @@
 
 #include <sys/types.h>
 #include <string.h>
+#ifndef _MSC_VER
+#include <strings.h>
+#endif
 #include <stdlib.h>
 #include <stdio.h>
 
