@@ -77,8 +77,8 @@ DlgReplaceCueColor::DlgReplaceCueColor(
     // from the rest of the application (when not styled via QSS), but that's
     // better than having buttons without any colors (which would make the
     // color picker unusable).
-    pushButtonNewColor->setStyle(m_pStyle);
-    pushButtonCurrentColor->setStyle(m_pStyle);
+    pushButtonNewColor->setStyle(m_pStyle.get());
+    pushButtonCurrentColor->setStyle(m_pStyle.get());
 
     // Set up new color button
     ColorPaletteSettings colorPaletteSettings(pConfig);
@@ -90,9 +90,11 @@ DlgReplaceCueColor::DlgReplaceCueColor(
     }
     setButtonColor(pushButtonNewColor, mixxx::RgbColor::toQColor(firstColor));
 
-    // Add menu for new color button
+    // Add menu for 'New color' button
     m_pNewColorPickerAction = make_parented<WColorPickerAction>(
-            WColorPicker::Option::AllowCustomColor,
+            WColorPicker::Option::AllowCustomColor |
+                    // TODO(xxx) remove this once the preferences are themed via QSS
+                    WColorPicker::Option::NoExtStyleSheet,
             colorPaletteSettings.getHotcueColorPalette(),
             this);
     m_pNewColorPickerAction->setObjectName("HotcueColorPickerAction");
@@ -110,7 +112,7 @@ DlgReplaceCueColor::DlgReplaceCueColor(
     m_pNewColorMenu->addAction(m_pNewColorPickerAction);
     pushButtonNewColor->setMenu(m_pNewColorMenu);
 
-    // Set up current color button
+    // Set up 'Current color' button
     setButtonColor(pushButtonCurrentColor,
             mixxx::RgbColor::toQColor(
                     mixxx::PredefinedColorPalettes::kDefaultCueColor));
@@ -122,13 +124,15 @@ DlgReplaceCueColor::DlgReplaceCueColor(
             this,
             &DlgReplaceCueColor::slotUpdateWidgets);
 
-    // Add menu for current color button
+    // Add menu for 'Current color' button
     m_pCurrentColorPickerAction = make_parented<WColorPickerAction>(
-            WColorPicker::Option::AllowCustomColor,
+            WColorPicker::Option::AllowCustomColor |
+                    // TODO(xxx) remove this once the preferences are themed via QSS
+                    WColorPicker::Option::NoExtStyleSheet,
             colorPaletteSettings.getHotcueColorPalette(),
             this);
     m_pCurrentColorPickerAction->setObjectName("HotcueColorPickerAction");
-    m_pNewColorPickerAction->setSelectedColor(
+    m_pCurrentColorPickerAction->setSelectedColor(
             mixxx::PredefinedColorPalettes::kDefaultCueColor);
     connect(m_pCurrentColorPickerAction,
             &WColorPickerAction::colorPicked,
@@ -173,9 +177,6 @@ DlgReplaceCueColor::DlgReplaceCueColor(
     slotUpdateWidgets();
 }
 
-DlgReplaceCueColor::~DlgReplaceCueColor() {
-}
-
 void DlgReplaceCueColor::setColorPalette(const ColorPalette& palette) {
     m_pNewColorPickerAction->setColorPalette(palette);
     QResizeEvent resizeNewColorMenuEvent(QSize(), m_pNewColorMenu->size());
