@@ -145,8 +145,8 @@ AutoDJProcessor::AutoDJProcessor(
     m_pEnabledAutoDJ = new ControlPushButton(
             ConfigKey("[AutoDJ]", "enabled"));
     m_pEnabledAutoDJ->setButtonMode(ControlPushButton::TOGGLE);
-    connect(m_pEnabledAutoDJ, &ControlObject::valueChanged,
-            this, &AutoDJProcessor::controlEnable);
+    m_pEnabledAutoDJ->connectValueChangeRequest(this,
+            &AutoDJProcessor::controlEnableChangeRequest);
 
     // TODO(rryan) listen to signals from PlayerManager and add/remove as decks
     // are created.
@@ -227,6 +227,7 @@ void AutoDJProcessor::fadeNow() {
     if (!pLeftDeck || !pRightDeck) {
         // User has changed the orientation, disable Auto DJ
         toggleAutoDJ(false);
+        emit autoDJError(ADJ_NOT_TWO_DECKS);
         return;
     }
 
@@ -259,6 +260,7 @@ void AutoDJProcessor::fadeNow() {
         // Deck is empty or track too short, disable AutoDJ
         // This happens only if the user has changed deck orientation to such deck.
         toggleAutoDJ(false);
+        emit autoDJError(ADJ_NOT_TWO_DECKS);
         return;
     }
 
@@ -333,6 +335,7 @@ void AutoDJProcessor::fadeNow() {
 
 AutoDJProcessor::AutoDJError AutoDJProcessor::skipNext() {
     if (m_eState == ADJ_DISABLED) {
+        emit autoDJError(ADJ_IS_INACTIVE);
         return ADJ_IS_INACTIVE;
     }
     // Load the next song from the queue.
@@ -341,6 +344,7 @@ AutoDJProcessor::AutoDJError AutoDJProcessor::skipNext() {
     if (!pLeftDeck || !pRightDeck) {
         // User has changed the orientation, disable Auto DJ
         toggleAutoDJ(false);
+        emit autoDJError(ADJ_NOT_TWO_DECKS);
         return ADJ_NOT_TWO_DECKS;
     }
 
@@ -373,6 +377,7 @@ AutoDJProcessor::AutoDJError AutoDJProcessor::toggleAutoDJ(bool enable) {
         if (!pLeftDeck || !pRightDeck) {
             // Keep the current state.
             emitAutoDJStateChanged(m_eState);
+            emit autoDJError(ADJ_NOT_TWO_DECKS);
             return ADJ_NOT_TWO_DECKS;
         }
 
@@ -383,6 +388,7 @@ AutoDJProcessor::AutoDJError AutoDJProcessor::toggleAutoDJ(bool enable) {
             qDebug() << "One deck must be stopped before enabling Auto DJ mode";
             // Keep the current state.
             emitAutoDJStateChanged(m_eState);
+            emit autoDJError(ADJ_BOTH_DECKS_PLAYING);
             return ADJ_BOTH_DECKS_PLAYING;
         }
 
@@ -391,6 +397,7 @@ AutoDJProcessor::AutoDJError AutoDJProcessor::toggleAutoDJ(bool enable) {
         for (int i = 2; i < m_decks.length(); ++i) {
             if (m_decks[i] && m_decks[i]->isPlaying()) {
                 // Keep the current state.
+                emit autoDJError(ADJ_DECKS_3_4_PLAYING);
                 return ADJ_DECKS_3_4_PLAYING;
             }
         }
@@ -419,18 +426,15 @@ AutoDJProcessor::AutoDJError AutoDJProcessor::toggleAutoDJ(bool enable) {
 
         TrackPointer nextTrack = getNextTrackFromQueue();
         if (!nextTrack) {
-            qDebug() << "Queue is empty now";
-            if (m_pEnabledAutoDJ->get() != 0.0) {
-                m_pEnabledAutoDJ->set(0.0);
-            }
+            qDebug() << "Queue is empty now, disable Auto DJ";
+            m_pEnabledAutoDJ->setAndConfirm(0.0);
             emitAutoDJStateChanged(m_eState);
+            emit autoDJError(ADJ_QUEUE_EMPTY);
             return ADJ_QUEUE_EMPTY;
         }
 
         // Track is available so GO
-        if (m_pEnabledAutoDJ->get() != 1.0) {
-            m_pEnabledAutoDJ->set(1.0);
-        }
+        m_pEnabledAutoDJ->setAndConfirm(1.0);
         qDebug() << "Auto DJ enabled";
 
         m_pCOCrossfader->connectValueChanged(this, &AutoDJProcessor::crossfaderChanged);
@@ -559,7 +563,7 @@ AutoDJProcessor::AutoDJError AutoDJProcessor::toggleAutoDJ(bool enable) {
         }
         emitAutoDJStateChanged(m_eState);
     } else { // Disable Auto DJ
-        m_pEnabledAutoDJ->set(0.0);
+        m_pEnabledAutoDJ->setAndConfirm(0.0);
         qDebug() << "Auto DJ disabled";
         m_eState = ADJ_DISABLED;
         disconnect(m_pCOCrossfader,
@@ -574,7 +578,7 @@ AutoDJProcessor::AutoDJError AutoDJProcessor::toggleAutoDJ(bool enable) {
     return ADJ_OK;
 }
 
-void AutoDJProcessor::controlEnable(double value) {
+void AutoDJProcessor::controlEnableChangeRequest(double value) {
     toggleAutoDJ(value > 0.0);
 }
 
@@ -625,6 +629,7 @@ void AutoDJProcessor::crossfaderChanged(double value) {
                     }
                     pToDeck->play();
                 } else {
+                    // Track in toDeck was ejected manually, stop.
                     toggleAutoDJ(false);
                     return;
                 }
@@ -1074,16 +1079,18 @@ void AutoDJProcessor::playerOutroEndChanged(DeckAttributes* pAttributes, double
 }
 
 double AutoDJProcessor::getIntroStartSecond(DeckAttributes* pDeck) {
+    double trackEndSample = pDeck->trackSamples();
     double introStartSample = pDeck->introStartPosition();
-    if (introStartSample == Cue::kNoPosition) {
+    if (introStartSample == Cue::kNoPosition || introStartSample > trackEndSample) {
         return getFirstSoundSecond(pDeck);
     }
     return samplePositionToSeconds(introStartSample, pDeck);
 }
 
 double AutoDJProcessor::getIntroEndSecond(DeckAttributes* pDeck) {
+    double trackEndSample = pDeck->trackSamples();
     double introEndSample = pDeck->introEndPosition();
-    if (introEndSample == Cue::kNoPosition) {
+    if (introEndSample == Cue::kNoPosition || introEndSample > trackEndSample) {
         // Assume a zero length intro if introEnd is not set.
         // The introStart is automatically placed by AnalyzerSilence, so use
         // that as a fallback if the user has not placed outroStart. If it has
@@ -1094,8 +1101,9 @@ double AutoDJProcessor::getIntroEndSecond(DeckAttributes* pDeck) {
 }
 
 double AutoDJProcessor::getOutroStartSecond(DeckAttributes* pDeck) {
+    double trackEndSample = pDeck->trackSamples();
     double outroStartSample = pDeck->outroStartPosition();
-    if (outroStartSample == Cue::kNoPosition) {
+    if (outroStartSample == Cue::kNoPosition || outroStartSample > trackEndSample) {
         // Assume a zero length outro if outroStart is not set.
         // The outroEnd is automatically placed by AnalyzerSilence, so use
         // that as a fallback if the user has not placed outroStart. If it has
@@ -1106,8 +1114,9 @@ double AutoDJProcessor::getOutroStartSecond(DeckAttributes* pDeck) {
 }
 
 double AutoDJProcessor::getOutroEndSecond(DeckAttributes* pDeck) {
+    double trackEndSample = pDeck->trackSamples();
     double outroEndSample = pDeck->outroEndPosition();
-    if (outroEndSample == Cue::kNoPosition) {
+    if (outroEndSample == Cue::kNoPosition || outroEndSample > trackEndSample) {
         return getLastSoundSecond(pDeck);
     }
     return samplePositionToSeconds(outroEndSample, pDeck);;
@@ -1123,7 +1132,14 @@ double AutoDJProcessor::getFirstSoundSecond(DeckAttributes* pDeck) {
     if (pFromTrackAudibleSound) {
         double firstSound = pFromTrackAudibleSound->getPosition();
         if (firstSound > 0.0) {
-            return samplePositionToSeconds(firstSound, pDeck);
+            double trackEndSample = pDeck->trackSamples();
+            if (firstSound <= trackEndSample) {
+                return samplePositionToSeconds(firstSound, pDeck);
+            } else {
+                qWarning() << "Audible Sound Cue starts after track end in:"
+                           << pTrack->getLocation()
+                           << "Using the first sample instead.";
+            }
         }
     }
     return 0.0;
@@ -1135,14 +1151,21 @@ double AutoDJProcessor::getLastSoundSecond(DeckAttributes* pDeck) {
         return 0.0;
     }
 
-    CuePointer pFromTrackAudibleSound = pTrack->findCueByType(mixxx::CueType::AudibleSound);
-    if (pFromTrackAudibleSound && pFromTrackAudibleSound->getLength() > 0) {
-        double lastSound = pFromTrackAudibleSound->getEndPosition();
+    double trackEndSample = pDeck->trackSamples();
+    CuePointer pCueAudibleSound = pTrack->findCueByType(mixxx::CueType::AudibleSound);
+    if (pCueAudibleSound && pCueAudibleSound->getLength() > 0) {
+        double lastSound = pCueAudibleSound->getEndPosition();
         if (lastSound > 0) {
-            return samplePositionToSeconds(lastSound, pDeck);
+            if (lastSound <= trackEndSample) {
+                return samplePositionToSeconds(lastSound, pDeck);
+            } else {
+                qWarning() << "Audible Sound Cue ends after track end in:"
+                           << pTrack->getLocation()
+                           << "Using the last sample instead.";
+            }
         }
     }
-    return getEndSecond(pDeck);
+    return samplePositionToSeconds(trackEndSample, pDeck);
 }
 
 double AutoDJProcessor::getEndSecond(DeckAttributes* pDeck) {
@@ -1151,8 +1174,8 @@ double AutoDJProcessor::getEndSecond(DeckAttributes* pDeck) {
         return 0.0;
     }
 
-    double endSamplePosition = pDeck->trackSamples();
-    return samplePositionToSeconds(endSamplePosition, pDeck);
+    double trackEndSample = pDeck->trackSamples();
+    return samplePositionToSeconds(trackEndSample, pDeck);
 }
 
 double AutoDJProcessor::samplePositionToSeconds(double samplePosition, DeckAttributes* pDeck) {
@@ -1255,12 +1278,11 @@ void AutoDJProcessor::calculateTransition(DeckAttributes* pFromDeck,
     }
 
     double introLength = 0;
-    const double introEndSample = pToDeck->introEndPosition();
-    if (introEndSample != Cue::kNoPosition) {
-        const double introEnd = samplePositionToSeconds(introEndSample, pToDeck);
-        if (introStart < introEnd) {
-            introLength = introEnd - introStart;
-        }
+
+    // This returns introStart in case the user has not yet set an intro end
+    const double introEnd = getIntroEndSecond(pToDeck);
+    if (introStart < introEnd) {
+        introLength = introEnd - introStart;
     }
 
     if constexpr (sDebug) {
@@ -1503,6 +1525,7 @@ void AutoDJProcessor::playerTrackLoaded(DeckAttributes* pDeck, TrackPointer pTra
             }
             // User has changed the orientation, disable Auto DJ
             toggleAutoDJ(false);
+            emit autoDJError(ADJ_NOT_TWO_DECKS);
             return;
         }
         pDeck->startPos = kKeepPosition;
@@ -1611,6 +1634,7 @@ void AutoDJProcessor::setTransitionTime(int time) {
         if (!pLeftDeck || !pRightDeck) {
             // User has changed the orientation, disable Auto DJ
             toggleAutoDJ(false);
+            emit autoDJError(ADJ_NOT_TWO_DECKS);
             return;
         }
         if (pLeftDeck->isPlaying()) {
@@ -1639,6 +1663,7 @@ void AutoDJProcessor::setTransitionMode(TransitionMode newMode) {
     if (!pLeftDeck || !pRightDeck) {
         // User has changed the orientation, disable Auto DJ
         toggleAutoDJ(false);
+        emit autoDJError(ADJ_NOT_TWO_DECKS);
         return;
     }
 
