@@ -17,35 +17,21 @@ constexpr bool sDebug = false;
 }  // namespace
 
 BaseTrackCache::BaseTrackCache(TrackCollection* pTrackCollection,
-                               const QString& tableName,
-                               const QString& idColumn,
-                               const QStringList& columns,
-                               bool isCaching)
-        : m_tableName(tableName),
-          m_idColumn(idColumn),
+        QString tableName,
+        QString idColumn,
+        QStringList columns,
+        QStringList searchColumns,
+        bool isCaching)
+        : m_tableName(std::move(tableName)),
+          m_idColumn(std::move(idColumn)),
           m_columnCount(columns.size()),
           m_columnsJoined(columns.join(",")),
-          m_columnCache(columns),
-          m_pQueryParser(new SearchQueryParser(pTrackCollection)),
+          m_columnCache(std::move(columns)),
+          m_pQueryParser(std::make_unique<SearchQueryParser>(
+                  pTrackCollection, std::move(searchColumns))),
           m_bIndexBuilt(false),
           m_bIsCaching(isCaching),
           m_database(pTrackCollection->database()) {
-    m_searchColumns << "artist"
-                    << "album"
-                    << "album_artist"
-                    << "location"
-                    << "grouping"
-                    << "comment"
-                    << "title"
-                    << "genre"
-                    << "crate";
-
-    // Convert all the search column names to their field indexes because we use
-    // them a bunch.
-    m_searchColumnIndices.resize(m_searchColumns.size());
-    for (int i = 0; i < m_searchColumns.size(); ++i) {
-        m_searchColumnIndices[i] = m_columnCache.fieldIndex(m_searchColumns[i]);
-    }
 }
 
 BaseTrackCache::~BaseTrackCache() {
@@ -125,10 +111,6 @@ void BaseTrackCache::ensureCached(const QSet<TrackId>& trackIds) {
     updateTracksInIndex(trackIds);
 }
 
-void BaseTrackCache::setSearchColumns(const QStringList& columns) {
-    m_searchColumns = columns;
-}
-
 const TrackPointer& BaseTrackCache::getRecentTrack(TrackId trackId) const {
     DEBUG_ASSERT(m_bIsCaching);
     // Only refresh the recently used track if the identifiers
@@ -212,7 +194,7 @@ bool BaseTrackCache::updateTrackInIndex(
         return false;
     }
     if (sDebug) {
-        qDebug() << "updateTrackInIndex:" << pTrack->getFileInfo();
+        qDebug() << "updateTrackInIndex:" << pTrack->getLocation();
     }
 
     int numColumns = columnCount();
@@ -228,7 +210,7 @@ bool BaseTrackCache::updateTrackInIndex(
             getTrackValueForColumn(pTrack, i, record[i]);
         }
         if (m_bIsCaching) {
-            replaceRecentTrack(std::move(trackId), std::move(pTrack));
+            replaceRecentTrack(std::move(trackId), pTrack);
         }
     } else {
         if (m_bIsCaching) {
@@ -488,7 +470,6 @@ void BaseTrackCache::filterAndSort(const QSet<TrackId>& trackIds,
     const std::unique_ptr<QueryNode> pQuery =
             m_pQueryParser->parseQuery(
                     searchQuery,
-                    m_searchColumns,
                     queryFragments.join(" AND "));
 
     QString filter = pQuery->toSql();
