@@ -43,10 +43,11 @@ class BaseTrackCache : public QObject {
     /// The order of the `columns` list parameter defines the initial/default
     /// order of columns in the library view.
     BaseTrackCache(TrackCollection* pTrackCollection,
-                   const QString& tableName,
-                   const QString& idColumn,
-                   const QStringList& columns,
-                   bool isCaching);
+            QString tableName,
+            QString idColumn,
+            QStringList columns,
+            QStringList searchColumns,
+            bool isCaching);
     ~BaseTrackCache() override;
 
     // Rebuild the BaseTrackCache index from the SQL table. This can be
@@ -73,7 +74,6 @@ class BaseTrackCache : public QObject {
     virtual bool isCached(TrackId trackId) const;
     virtual void ensureCached(TrackId trackId);
     virtual void ensureCached(const QSet<TrackId>& trackIds);
-    virtual void setSearchColumns(const QStringList& columns);
 
   signals:
     void tracksChanged(const QSet<TrackId>& trackIds);
@@ -126,9 +126,6 @@ class BaseTrackCache : public QObject {
 
     const StringCollator m_collator;
 
-    QStringList m_searchColumns;
-    QVector<int> m_searchColumnIndices;
-
     // Temporary storage for filterAndSort()
 
     QVector<TrackId> m_trackOrder;
