@@ -11,7 +11,6 @@
 
 #include "util/logger.h"
 
-
 namespace {
 
 const mixxx::Logger kLogger("CrateStorage");
@@ -57,7 +56,6 @@ const QString kCrateSummaryViewQuery = QString(
                     CRATE_TABLE,
                     CRATETABLE_ID);
 
-
 class CrateQueryBinder {
   public:
     explicit CrateQueryBinder(FwdSqlQuery& query)
@@ -104,8 +102,6 @@ QString joinSqlStringList(const QList<TrackId>& trackIds) {
 
 } // anonymous namespace
 
-
-
 CrateQueryFields::CrateQueryFields(const FwdSqlQuery& query)
     : m_iId(query.fieldIndex(CRATETABLE_ID)),
       m_iName(query.fieldIndex(CRATETABLE_NAME)),
@@ -113,7 +109,6 @@ CrateQueryFields::CrateQueryFields(const FwdSqlQuery& query)
       m_iAutoDjSource(query.fieldIndex(CRATETABLE_AUTODJ_SOURCE)) {
 }
 
-
 void CrateQueryFields::populateFromQuery(
         const FwdSqlQuery& query,
         Crate* pCrate) const {
@@ -123,7 +118,6 @@ void CrateQueryFields::populateFromQuery(
     pCrate->setAutoDjSource(isAutoDjSource(query));
 }
 
-
 CrateTrackQueryFields::CrateTrackQueryFields(const FwdSqlQuery& query)
     : m_iCrateId(query.fieldIndex(CRATETRACKSTABLE_CRATEID)),
       m_iTrackId(query.fieldIndex(CRATETRACKSTABLE_TRACKID)) {
@@ -243,7 +237,6 @@ void CrateStorage::disconnectDatabase() {
     m_database = QSqlDatabase();
 }
 
-
 void CrateStorage::createViews() {
     VERIFY_OR_DEBUG_ASSERT(FwdSqlQuery(m_database, kCrateSummaryViewQuery).execPrepared()) {
         kLogger.critical()
@@ -251,7 +244,6 @@ void CrateStorage::createViews() {
     }
 }
 
-
 uint CrateStorage::countCrates() const {
     FwdSqlQuery query(m_database, QString(
             "SELECT COUNT(*) FROM %1").arg(
@@ -265,7 +257,6 @@ uint CrateStorage::countCrates() const {
     }
 }
 
-
 bool CrateStorage::readCrateById(CrateId id, Crate* pCrate) const {
     FwdSqlQuery query(m_database, QString(
             "SELECT * FROM %1 WHERE %2=:id").arg(
@@ -288,7 +279,6 @@ bool CrateStorage::readCrateById(CrateId id, Crate* pCrate) const {
     return false;
 }
 
-
 bool CrateStorage::readCrateByName(const QString& name, Crate* pCrate) const {
     FwdSqlQuery query(m_database, QString(
             "SELECT * FROM %1 WHERE %2=:name").arg(
@@ -314,7 +304,6 @@ bool CrateStorage::readCrateByName(const QString& name, Crate* pCrate) const {
     return false;
 }
 
-
 CrateSelectResult CrateStorage::selectCrates() const {
     FwdSqlQuery query(m_database,
             mixxx::DbConnection::collateLexicographically(QString(
@@ -329,7 +318,6 @@ CrateSelectResult CrateStorage::selectCrates() const {
     }
 }
 
-
 CrateSelectResult CrateStorage::selectCratesByIds(
         const QString& subselectForCrateIds,
         SqlSubselectMode subselectMode) const {
@@ -369,7 +357,6 @@ CrateSelectResult CrateStorage::selectCratesByIds(
     }
 }
 
-
 CrateSelectResult CrateStorage::selectAutoDjCrates(bool autoDjSource) const {
     FwdSqlQuery query(m_database,
             mixxx::DbConnection::collateLexicographically(QString(
@@ -385,7 +372,6 @@ CrateSelectResult CrateStorage::selectAutoDjCrates(bool autoDjSource) const {
     }
 }
 
-
 CrateSummarySelectResult CrateStorage::selectCrateSummaries() const {
     FwdSqlQuery query(m_database,
             mixxx::DbConnection::collateLexicographically(QString(
@@ -421,7 +407,6 @@ bool CrateStorage::readCrateSummaryById(CrateId id, CrateSummary* pCrateSummary)
     return false;
 }
 
-
 uint CrateStorage::countCrateTracks(CrateId crateId) const {
     FwdSqlQuery query(m_database, QString(
             "SELECT COUNT(*) FROM %1 WHERE %2=:crateId").arg(
@@ -437,7 +422,6 @@ uint CrateStorage::countCrateTracks(CrateId crateId) const {
     }
 }
 
-
 //static
 QString CrateStorage::formatSubselectQueryForCrateTrackIds(
         CrateId crateId) {
@@ -472,8 +456,6 @@ QString CrateStorage::formatQueryForTrackIdsWithCrate() {
             CRATETABLE_ID);
 }
 
-
-
 CrateTrackSelectResult CrateStorage::selectCrateTracksSorted(CrateId crateId) const {
     FwdSqlQuery query(m_database, QString(
             "SELECT * FROM %1 WHERE %2=:crateId ORDER BY %3").arg(
@@ -488,7 +470,6 @@ CrateTrackSelectResult CrateStorage::selectCrateTracksSorted(CrateId crateId) co
     }
 }
 
-
 CrateTrackSelectResult CrateStorage::selectTrackCratesSorted(TrackId trackId) const {
     FwdSqlQuery query(m_database, QString(
             "SELECT * FROM %1 WHERE %2=:trackId ORDER BY %3").arg(
@@ -504,19 +485,21 @@ CrateTrackSelectResult CrateStorage::selectTrackCratesSorted(TrackId trackId) co
 }
 
 CrateSummarySelectResult CrateStorage::selectCratesWithTrackCount(const QList<TrackId>& trackIds) const {
-    FwdSqlQuery query(m_database, QString(
-        "SELECT *, ("
-        "    SELECT COUNT(*) FROM %1 WHERE %2.%3 = %1.%4 and %1.%5 in (%9)"
-        " ) AS %6, 0 as %7 FROM %2 ORDER BY %8").arg(
-                CRATE_TRACKS_TABLE,
-                CRATE_TABLE,
-                CRATETABLE_ID,
-                CRATETRACKSTABLE_CRATEID,
-                CRATETRACKSTABLE_TRACKID,
-                CRATESUMMARY_TRACK_COUNT,
-                CRATESUMMARY_TRACK_DURATION,
-                CRATETABLE_NAME,
-                joinSqlStringList(trackIds)));
+    FwdSqlQuery query(m_database,
+            mixxx::DbConnection::collateLexicographically(
+                    QString("SELECT *, ("
+                            "    SELECT COUNT(*) FROM %1 WHERE %2.%3 = %1.%4 "
+                            "and %1.%5 in (%9)"
+                            " ) AS %6, 0 as %7 FROM %2 ORDER BY %8")
+                            .arg(CRATE_TRACKS_TABLE,
+                                    CRATE_TABLE,
+                                    CRATETABLE_ID,
+                                    CRATETRACKSTABLE_CRATEID,
+                                    CRATETRACKSTABLE_TRACKID,
+                                    CRATESUMMARY_TRACK_COUNT,
+                                    CRATESUMMARY_TRACK_DURATION,
+                                    CRATETABLE_NAME,
+                                    joinSqlStringList(trackIds))));
 
     if (query.execPrepared()) {
         return CrateSummarySelectResult(std::move(query));
@@ -574,7 +557,6 @@ QSet<CrateId> CrateStorage::collectCrateIdsOfTracks(const QList<TrackId>& trackI
     return trackCrates;
 }
 
-
 bool CrateStorage::onInsertingCrate(
         const Crate& crate,
         CrateId* pCrateId) {
@@ -611,7 +593,6 @@ bool CrateStorage::onInsertingCrate(
     }
 }
 
-
 bool CrateStorage::onUpdatingCrate(
         const Crate& crate) {
     VERIFY_OR_DEBUG_ASSERT(crate.getId().isValid()) {
@@ -650,7 +631,6 @@ bool CrateStorage::onUpdatingCrate(
     }
 }
 
-
 bool CrateStorage::onDeletingCrate(
         CrateId crateId) {
     VERIFY_OR_DEBUG_ASSERT(crateId.isValid()) {
@@ -704,7 +684,6 @@ bool CrateStorage::onDeletingCrate(
     }
 }
 
-
 bool CrateStorage::onAddingCrateTracks(
         CrateId crateId,
         const QList<TrackId>& trackIds) {
@@ -736,7 +715,6 @@ bool CrateStorage::onAddingCrateTracks(
     return true;
 }
 
-
 bool CrateStorage::onRemovingCrateTracks(
         CrateId crateId,
         const QList<TrackId>& trackIds) {
@@ -770,7 +748,6 @@ bool CrateStorage::onRemovingCrateTracks(
     return true;
 }
 
-
 bool CrateStorage::onPurgingTracks(
         const QList<TrackId>& trackIds) {
     // NOTE(uklotzde): Remove tracks from crates one-by-one.
