@@ -162,6 +162,9 @@ bool dropTable(QSqlDatabase& database, const QString& tableName) {
 }
 
 // This function is executed in a separate thread other than the main thread
+// The returned list owns the pointers, but we can't use a unique_ptr because
+// the result is passed by a const reference inside QFuture and than copied
+// to the main thread requiring a copy-able object.
 QList<TreeItem*> findRekordboxDevices() {
     QThread* thisThread = QThread::currentThread();
     thisThread->setPriority(QThread::LowPriority);
@@ -192,10 +195,10 @@ QList<TreeItem*> findRekordboxDevices() {
             QList<QString> data;
             data << drive.filePath();
             data << IS_RECORDBOX_DEVICE;
-            TreeItem* foundDevice = new TreeItem(
+            auto* pFoundDevice = new TreeItem(
                     std::move(displayPath),
                     QVariant(data));
-            foundDevices << foundDevice;
+            foundDevices << pFoundDevice;
         }
     }
 #elif defined(__LINUX__)
@@ -223,10 +226,10 @@ QList<TreeItem*> findRekordboxDevices() {
             QList<QString> data;
             data << device.filePath();
             data << IS_RECORDBOX_DEVICE;
-            TreeItem* foundDevice = new TreeItem(
+            auto* pFoundDevice = new TreeItem(
                     device.fileName(),
                     QVariant(data));
-            foundDevices << foundDevice;
+            foundDevices << pFoundDevice;
         }
     }
 #else // __APPLE__
@@ -239,10 +242,10 @@ QList<TreeItem*> findRekordboxDevices() {
             QList<QString> data;
             data << device.filePath();
             data << IS_RECORDBOX_DEVICE;
-            auto* foundDevice = new TreeItem(
+            auto* pFoundDevice = new TreeItem(
                     device.fileName(),
                     QVariant(data));
-            foundDevices << foundDevice;
+            foundDevices << pFoundDevice;
         }
     }
 #endif
@@ -492,7 +495,7 @@ QString parseDeviceDB(mixxx::DbConnectionPoolPtr dbConnectionPool, TreeItem* dev
     // There are other types of tables (eg. COLOR), these are the only ones we are
     // interested at the moment. Perhaps when/if
     // https://bugs.launchpad.net/mixxx/+bug/1100882
-    // is completed, this can be revisted.
+    // is completed, this can be revisited.
     // Attempt was made to also recover HISTORY
     // playlists (which are found on removable Rekordbox devices), however
     // they didn't appear to contain valid row_ref_t structures.
@@ -634,6 +637,9 @@ void buildPlaylistTree(
         const QString& device) {
     for (uint32_t childIndex = 0; childIndex < (uint32_t)playlistTreeMap[parentID].size(); childIndex++) {
         uint32_t childID = playlistTreeMap[parentID][childIndex];
+        if (childID == 0) {
+            continue;
+        }
         QString playlistItemName = playlistNameMap[childID];
 
         QString currentPath = playlistPath + kPLaylistPathDelimiter + playlistItemName;
@@ -1230,42 +1236,42 @@ RekordboxFeature::RekordboxFeature(
           m_icon(":/images/library/ic_library_rekordbox.svg") {
     QString tableName = kRekordboxLibraryTable;
     QString idColumn = LIBRARYTABLE_ID;
-    QStringList columns;
-    columns << LIBRARYTABLE_ID
-            << LIBRARYTABLE_ARTIST
-            << LIBRARYTABLE_TITLE
-            << LIBRARYTABLE_ALBUM
-            << LIBRARYTABLE_YEAR
-            << LIBRARYTABLE_GENRE
-            << LIBRARYTABLE_TRACKNUMBER
-            << TRACKLOCATIONSTABLE_LOCATION
-            << LIBRARYTABLE_COMMENT
-            << LIBRARYTABLE_RATING
-            << LIBRARYTABLE_DURATION
-            << LIBRARYTABLE_BITRATE
-            << LIBRARYTABLE_BPM
-            << LIBRARYTABLE_KEY
-            << LIBRARYTABLE_COLOR
-            << REKORDBOX_ANALYZE_PATH;
-    m_trackSource = QSharedPointer<BaseTrackCache>(
-            new BaseTrackCache(m_pTrackCollection, tableName, idColumn, columns, false));
-    QStringList searchColumns;
-    searchColumns
-            << LIBRARYTABLE_ARTIST
-            << LIBRARYTABLE_TITLE
-            << LIBRARYTABLE_ALBUM
-            << LIBRARYTABLE_YEAR
-            << LIBRARYTABLE_GENRE
-            << LIBRARYTABLE_TRACKNUMBER
-            << TRACKLOCATIONSTABLE_LOCATION
-            << LIBRARYTABLE_COMMENT
-            << LIBRARYTABLE_DURATION
-            << LIBRARYTABLE_BITRATE
-            << LIBRARYTABLE_BPM
-            << LIBRARYTABLE_KEY;
-    m_trackSource->setSearchColumns(searchColumns);
+    QStringList columns = {
+            LIBRARYTABLE_ID,
+            LIBRARYTABLE_ARTIST,
+            LIBRARYTABLE_TITLE,
+            LIBRARYTABLE_ALBUM,
+            LIBRARYTABLE_YEAR,
+            LIBRARYTABLE_GENRE,
+            LIBRARYTABLE_TRACKNUMBER,
+            TRACKLOCATIONSTABLE_LOCATION,
+            LIBRARYTABLE_COMMENT,
+            LIBRARYTABLE_RATING,
+            LIBRARYTABLE_DURATION,
+            LIBRARYTABLE_BITRATE,
+            LIBRARYTABLE_BPM,
+            LIBRARYTABLE_KEY,
+            LIBRARYTABLE_COLOR,
+            REKORDBOX_ANALYZE_PATH};
 
-    m_pRekordboxPlaylistModel = new RekordboxPlaylistModel(this, pLibrary->trackCollections(), m_trackSource);
+    const QStringList searchColumns = {
+            LIBRARYTABLE_ARTIST,
+            LIBRARYTABLE_TITLE,
+            LIBRARYTABLE_ALBUM,
+            LIBRARYTABLE_GENRE,
+            LIBRARYTABLE_TRACKNUMBER,
+            TRACKLOCATIONSTABLE_LOCATION,
+            LIBRARYTABLE_COMMENT};
+
+    m_trackSource = QSharedPointer<BaseTrackCache>::create(
+            m_pTrackCollection,
+            tableName,
+            std::move(idColumn),
+            std::move(columns),
+            std::move(searchColumns),
+            false);
+    m_pRekordboxPlaylistModel = make_parented<RekordboxPlaylistModel>(
+            this, pLibrary->trackCollections(), m_trackSource);
 
     m_title = tr("Rekordbox");
 
@@ -1305,18 +1311,16 @@ RekordboxFeature::~RekordboxFeature() {
     dropTable(database, kRekordboxPlaylistsTable);
     dropTable(database, kRekordboxLibraryTable);
     transaction.commit();
-
-    delete m_pRekordboxPlaylistModel;
 }
 
-void RekordboxFeature::bindLibraryWidget(WLibrary* libraryWidget,
+void RekordboxFeature::bindLibraryWidget(WLibrary* pLibraryWidget,
         KeyboardEventFilter* keyboard) {
     Q_UNUSED(keyboard);
-    WLibraryTextBrowser* edit = new WLibraryTextBrowser(libraryWidget);
-    edit->setHtml(formatRootViewHtml());
-    edit->setOpenLinks(false);
-    connect(edit, &WLibraryTextBrowser::anchorClicked, this, &RekordboxFeature::htmlLinkClicked);
-    libraryWidget->registerView("REKORDBOXHOME", edit);
+    parented_ptr<WLibraryTextBrowser> pEdit = make_parented<WLibraryTextBrowser>(pLibraryWidget);
+    pEdit->setHtml(formatRootViewHtml());
+    pEdit->setOpenLinks(false);
+    connect(pEdit, &WLibraryTextBrowser::anchorClicked, this, &RekordboxFeature::htmlLinkClicked);
+    pLibraryWidget->registerView("REKORDBOXHOME", pEdit);
 }
 
 void RekordboxFeature::htmlLinkClicked(const QUrl& link) {
@@ -1327,10 +1331,12 @@ void RekordboxFeature::htmlLinkClicked(const QUrl& link) {
     }
 }
 
-BaseSqlTableModel* RekordboxFeature::getPlaylistModelForPlaylist(const QString& playlist) {
-    RekordboxPlaylistModel* model = new RekordboxPlaylistModel(this, m_pLibrary->trackCollections(), m_trackSource);
-    model->setPlaylist(playlist);
-    return model;
+std::unique_ptr<BaseSqlTableModel>
+RekordboxFeature::createPlaylistModelForPlaylist(const QString& playlist) {
+    auto pModel = std::make_unique<RekordboxPlaylistModel>(
+            this, m_pLibrary->trackCollections(), m_trackSource);
+    pModel->setPlaylist(playlist);
+    return pModel;
 }
 
 QVariant RekordboxFeature::title() {
@@ -1452,9 +1458,12 @@ void RekordboxFeature::activateChild(const QModelIndex& index) {
 }
 
 void RekordboxFeature::onRekordboxDevicesFound() {
-    QList<TreeItem*> foundDevices = m_devicesFuture.result();
-    TreeItem* root = m_childModel.getRootItem();
+    const QList<TreeItem*> result = m_devicesFuture.result();
+    auto foundDevices = std::vector<std::unique_ptr<TreeItem>>(result.cbegin(), result.cend());
 
+    clearLastRightClickedIndex();
+
+    TreeItem* root = m_childModel.getRootItem();
     QSqlDatabase database = m_pTrackCollection->database();
 
     if (foundDevices.size() == 0) {
@@ -1481,10 +1490,8 @@ void RekordboxFeature::onRekordboxDevicesFound() {
             TreeItem* child = root->child(deviceIndex);
             bool removeChild = true;
 
-            for (int foundDeviceIndex = 0; foundDeviceIndex < foundDevices.size(); foundDeviceIndex++) {
-                TreeItem* deviceFound = foundDevices[foundDeviceIndex];
-
-                if (deviceFound->getLabel() == child->getLabel()) {
+            for (const auto& pDeviceFound : foundDevices) {
+                if (pDeviceFound->getLabel() == child->getLabel()) {
                     removeChild = false;
                     break;
                 }
@@ -1498,28 +1505,26 @@ void RekordboxFeature::onRekordboxDevicesFound() {
             }
         }
 
-        QList<TreeItem*> childrenToAdd;
+        std::vector<std::unique_ptr<TreeItem>> childrenToAdd;
 
-        for (int foundDeviceIndex = 0; foundDeviceIndex < foundDevices.size(); foundDeviceIndex++) {
-            TreeItem* deviceFound = foundDevices[foundDeviceIndex];
+        for (auto&& pDeviceFound : foundDevices) {
             bool addNewChild = true;
-
             for (int deviceIndex = 0; deviceIndex < root->childRows(); deviceIndex++) {
                 TreeItem* child = root->child(deviceIndex);
 
-                if (deviceFound->getLabel() == child->getLabel()) {
+                if (pDeviceFound->getLabel() == child->getLabel()) {
                     // This device already exists in the TreeModel, don't add or parse is again
                     addNewChild = false;
                 }
             }
 
             if (addNewChild) {
-                childrenToAdd << deviceFound;
+                childrenToAdd.push_back(std::move(pDeviceFound));
             }
         }
 
         if (!childrenToAdd.empty()) {
-            m_childModel.insertTreeItemRows(childrenToAdd, 0);
+            m_childModel.insertTreeItemRows(std::move(childrenToAdd), 0);
         }
     }
 
