@@ -81,7 +81,7 @@ PlayerManager::PlayerManager(UserSettingsPointer pConfig,
             &PlayerManager::slotChangeNumAuxiliaries, Qt::DirectConnection);
 
     // This is parented to the PlayerManager so does not need to be deleted
-    m_pSamplerBank = new SamplerBank(this);
+    m_pSamplerBank = new SamplerBank(m_pConfig, this);
 
     m_cloneTimer.start();
 }
