@@ -79,6 +79,7 @@
 #include "widget/wtracktext.h"
 #include "widget/wtrackwidgetgroup.h"
 #include "widget/wvumeter.h"
+#include "widget/wvumetergl.h"
 #include "widget/wwaveformviewer.h"
 #include "widget/wwidget.h"
 #include "widget/wwidgetgroup.h"
@@ -527,9 +528,7 @@ QList<QWidget*> LegacySkinParser::parseNode(const QDomElement& node) {
     } else if (nodeName == "StarRating") {
         result = wrapWidget(parseStarRating(node));
     } else if (nodeName == "VuMeter") {
-        WVuMeter* pVuMeterWidget = parseStandardWidget<WVuMeter>(node);
-        WaveformWidgetFactory::instance()->addTimerListener(pVuMeterWidget);
-        result = wrapWidget(pVuMeterWidget);
+        result = wrapWidget(parseVuMeter(node));
     } else if (nodeName == "StatusLight") {
         result = wrapWidget(parseStandardWidget<WStatusLight>(node));
     } else if (nodeName == "Display") {
@@ -718,7 +717,6 @@ QWidget* LegacySkinParser::parseWidgetGroup(const QDomElement& node) {
 
 QWidget* LegacySkinParser::parseWidgetStack(const QDomElement& node) {
     ControlObject* pNextControl = controlFromConfigNode(node.toElement(), "NextControl");
-    ;
     ConfigKey nextConfigKey;
     if (pNextControl != nullptr) {
         nextConfigKey = pNextControl->getKey();
@@ -966,16 +964,12 @@ QWidget* LegacySkinParser::parseOverview(const QDomElement& node) {
     overviewWidget->setup(node, *m_pContext);
     overviewWidget->installEventFilter(m_pKeyboard);
     overviewWidget->installEventFilter(m_pControllerManager->getControllerLearningEventFilter());
-    overviewWidget->Init();
+    overviewWidget->initWithTrack(pPlayer->getLoadedTrack());
 
     // Connect the player's load and unload signals to the overview widget.
     connect(pPlayer, &BaseTrackPlayer::newTrackLoaded, overviewWidget, &WOverview::slotTrackLoaded);
     connect(pPlayer, &BaseTrackPlayer::loadingTrack, overviewWidget, &WOverview::slotLoadingTrack);
 
-    // just in case track already loaded
-    overviewWidget->slotLoadingTrack(pPlayer->getLoadedTrack(), TrackPointer());
-    overviewWidget->slotTrackLoaded(pPlayer->getLoadedTrack());
-
     return overviewWidget;
 }
 
@@ -989,8 +983,8 @@ QWidget* LegacySkinParser::parseVisual(const QDomElement& node) {
 
     WWaveformViewer* viewer = new WWaveformViewer(group, m_pConfig, m_pParent);
     viewer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    WaveformWidgetFactory* factory = WaveformWidgetFactory::instance();
-    factory->setWaveformWidget(viewer, node, *m_pContext);
+    WaveformWidgetFactory* pFactory = WaveformWidgetFactory::instance();
+    pFactory->setWaveformWidget(viewer, node, *m_pContext);
 
     //qDebug() << "::parseVisual: parent" << m_pParent << m_pParent->size();
     //qDebug() << "::parseVisual: viewer" << viewer << viewer->size();
@@ -1254,10 +1248,10 @@ QWidget* LegacySkinParser::parseSpinny(const QDomElement& node) {
         return dummy;
     }
 
-    auto* waveformWidgetFactory = WaveformWidgetFactory::instance();
+    auto* pWaveformWidgetFactory = WaveformWidgetFactory::instance();
 
-    if (!waveformWidgetFactory->isOpenGlAvailable() &&
-            !waveformWidgetFactory->isOpenGlesAvailable()) {
+    if (!pWaveformWidgetFactory->isOpenGlAvailable() &&
+            !pWaveformWidgetFactory->isOpenGlesAvailable()) {
         WLabel* dummy = new WLabel(m_pParent);
         //: Shown when Spinny can not be displayed. Please keep \n unchanged
         dummy->setText(tr("No OpenGL\nsupport."));
@@ -1270,22 +1264,87 @@ QWidget* LegacySkinParser::parseSpinny(const QDomElement& node) {
         SKIN_WARNING(node, *m_pContext) << "No player found for group:" << group;
         return nullptr;
     }
-    WSpinny* spinny = new WSpinny(m_pParent, group, m_pConfig, m_pVCManager, pPlayer);
-    commonWidgetSetup(node, spinny);
+    // Note: For some reasons on X11 we need to create the widget without a parent to avoid to
+    // create two platform windows (QXcbWindow) in QWidget::create() for this widget.
+    // This happens, because the QWidget::create() of a parent() will populate all children
+    // with platform windows q_createNativeChildrenAndSetParent() while another window is already
+    // under construction. The ID for the first window is not cleared and leads to a segfault
+    // during on shutdown. This has been tested with Qt 5.12.8 and 5.15.3
+    WSpinny* pSpinny;
+    if (qApp->platformName() == QLatin1String("xcb")) {
+        pSpinny = new WSpinny(nullptr, group, m_pConfig, m_pVCManager, pPlayer);
+        pSpinny->setParent(m_pParent);
+    } else {
+        pSpinny = new WSpinny(m_pParent, group, m_pConfig, m_pVCManager, pPlayer);
+    }
+    commonWidgetSetup(node, pSpinny);
 
-    connect(waveformWidgetFactory,
+    connect(pWaveformWidgetFactory,
             &WaveformWidgetFactory::renderSpinnies,
-            spinny,
+            pSpinny,
             &WSpinny::render);
-    connect(waveformWidgetFactory, &WaveformWidgetFactory::swapSpinnies, spinny, &WSpinny::swap);
-    connect(spinny, &WSpinny::trackDropped, m_pPlayerManager, &PlayerManager::slotLoadToPlayer);
-    connect(spinny, &WSpinny::cloneDeck, m_pPlayerManager, &PlayerManager::slotCloneDeck);
+    connect(pWaveformWidgetFactory, &WaveformWidgetFactory::swapSpinnies, pSpinny, &WSpinny::swap);
+    connect(pSpinny, &WSpinny::trackDropped, m_pPlayerManager, &PlayerManager::slotLoadToPlayer);
+    connect(pSpinny, &WSpinny::cloneDeck, m_pPlayerManager, &PlayerManager::slotCloneDeck);
 
-    spinny->setup(node, *m_pContext);
-    spinny->installEventFilter(m_pKeyboard);
-    spinny->installEventFilter(m_pControllerManager->getControllerLearningEventFilter());
-    spinny->Init();
-    return spinny;
+    pSpinny->setup(node, *m_pContext);
+    pSpinny->installEventFilter(m_pKeyboard);
+    pSpinny->installEventFilter(m_pControllerManager->getControllerLearningEventFilter());
+    pSpinny->Init();
+    return pSpinny;
+}
+
+QWidget* LegacySkinParser::parseVuMeter(const QDomElement& node) {
+    auto* pWaveformWidgetFactory = WaveformWidgetFactory::instance();
+    if (!CmdlineArgs::Instance().getUseVuMeterGL() ||
+            (!pWaveformWidgetFactory->isOpenGlAvailable() &&
+                    !pWaveformWidgetFactory->isOpenGlesAvailable())) {
+        // Standard WVuMeter
+        WVuMeter* pVuMeterWidget = parseStandardWidget<WVuMeter>(node);
+        pWaveformWidgetFactory->addVuMeter(pVuMeterWidget);
+        return pVuMeterWidget;
+    }
+
+    // QGLWidget derived WVuMeterGL
+
+    if (CmdlineArgs::Instance().getSafeMode()) {
+        WLabel* dummy = new WLabel(m_pParent);
+        //: Shown when Mixxx is running in safe mode.
+        dummy->setText(tr("Safe Mode Enabled"));
+        return dummy;
+    }
+
+    if (!pWaveformWidgetFactory->isOpenGlAvailable() &&
+            !pWaveformWidgetFactory->isOpenGlesAvailable()) {
+        WLabel* dummy = new WLabel(m_pParent);
+        //: Shown when VuMeter can not be displayed. Please keep \n unchanged
+        dummy->setText(tr("No OpenGL\nsupport."));
+        return dummy;
+    }
+    // Note: For some reasons on X11 we need to create the widget without a parent to avoid to
+    // create two platform windows (QXcbWindow) in QWidget::create() for this widget.
+    // This happens, because the QWidget::create() of a parent() will populate all children
+    // with platform windows q_createNativeChildrenAndSetParent() while another window is already
+    // under construction. The ID for the first window is not cleared and leads to a segfault
+    // during on shutdown. This has been tested with Qt 5.12.8 and 5.15.3
+    WVuMeterGL* pVuMeterWidget;
+    if (qApp->platformName() == QLatin1String("xcb")) {
+        pVuMeterWidget = new WVuMeterGL();
+        pVuMeterWidget->setParent(m_pParent);
+    } else {
+        pVuMeterWidget = new WVuMeterGL(m_pParent);
+    }
+    commonWidgetSetup(node, pVuMeterWidget);
+
+    pWaveformWidgetFactory->addVuMeter(pVuMeterWidget);
+
+    pVuMeterWidget->setup(node, *m_pContext);
+    pVuMeterWidget->installEventFilter(m_pKeyboard);
+    pVuMeterWidget->installEventFilter(
+            m_pControllerManager->getControllerLearningEventFilter());
+    pVuMeterWidget->Init();
+
+    return pVuMeterWidget;
 }
 
 QWidget* LegacySkinParser::parseSearchBox(const QDomElement& node) {
