@@ -30,9 +30,10 @@ const int kNetworkLatencyFrames = 8192; // 185 ms @ 44100 Hz
 const mixxx::Logger kLogger("SoundDeviceNetwork");
 } // namespace
 
-SoundDeviceNetwork::SoundDeviceNetwork(UserSettingsPointer config,
-                                       SoundManager *sm,
-                                       QSharedPointer<EngineNetworkStream> pNetworkStream)
+SoundDeviceNetwork::SoundDeviceNetwork(
+        UserSettingsPointer config,
+        SoundManager* sm,
+        QSharedPointer<EngineNetworkStream> pNetworkStream)
         : SoundDevice(config, sm),
           m_pNetworkStream(pNetworkStream),
           m_inputDrift(false),
@@ -63,46 +64,46 @@ SoundDeviceError SoundDeviceNetwork::open(bool isClkRefDevice, int syncBuffers)
         m_dSampleRate = 44100.0;
     }
 
-    qDebug() << "framesPerBuffer:" << m_framesPerBuffer;
-
-    m_audioBufferTime = mixxx::Duration::fromSeconds(
-            m_framesPerBuffer / m_dSampleRate);
-    qDebug() << "Requested sample rate: " << m_dSampleRate << "Hz, latency:"
-             << m_audioBufferTime;
+    const SINT framesPerBuffer = m_configFramesPerBuffer;
+    const auto requestedBufferTime = mixxx::Duration::fromSeconds(
+            framesPerBuffer / m_dSampleRate);
 
     // Feed the network device buffer directly from the
     // clock reference device callback
     // This is what should work best.
     if (m_iNumOutputChannels) {
-        m_outputFifo = std::make_unique<FIFO<CSAMPLE> >(
-                m_iNumOutputChannels * m_framesPerBuffer * 2);
+        m_outputFifo = std::make_unique<FIFO<CSAMPLE>>(
+                m_iNumOutputChannels * framesPerBuffer * 2);
     }
     if (m_iNumInputChannels) {
-        m_inputFifo = std::make_unique<FIFO<CSAMPLE> >(
-                m_iNumInputChannels * m_framesPerBuffer * 2);
+        m_inputFifo = std::make_unique<FIFO<CSAMPLE>>(
+                m_iNumInputChannels * framesPerBuffer * 2);
     }
 
     m_pNetworkStream->startStream(m_dSampleRate);
 
     // Create the callback Thread if requested
     if (isClkRefDevice) {
+        kLogger.debug() << "Clock Reference with:" << framesPerBuffer << "frames/buffer @"
+                        << m_dSampleRate << "Hz =" << requestedBufferTime.formatMillisWithUnit();
+
         // Update the samplerate and latency ControlObjects, which allow the
         // waveform view to properly correct for the latency.
         ControlObject::set(ConfigKey("[Master]", "latency"),
-                m_audioBufferTime.toDoubleMillis());
+                requestedBufferTime.toDoubleMillis());
         ControlObject::set(ConfigKey("[Master]", "samplerate"), m_dSampleRate);
-        ControlObject::set(ConfigKey("[Master]", "audio_buffer_size"),
-                m_audioBufferTime.toDoubleMillis());
 
         // Network stream was just started above so we have to wait until
         // we can pass one chunk.
         // The first callback runs early to do the one time setups
-        m_targetTime = m_audioBufferTime.toIntegerMicros();
+        m_targetTime = requestedBufferTime.toIntegerMicros();
 
         m_pThread = std::make_unique<SoundDeviceNetworkThread>(this);
         m_pThread->start(QThread::TimeCriticalPriority);
+    } else {
+        kLogger.debug() << "Maximum:" << framesPerBuffer << "frames/buffer @"
+                        << m_dSampleRate << "Hz =" << requestedBufferTime.formatMillisWithUnit();
     }
-
     return SOUNDDEVICE_ERROR_OK;
 }
 
@@ -129,12 +130,13 @@ QString SoundDeviceNetwork::getError() const {
     return QString();
 }
 
-void SoundDeviceNetwork::readProcess() {
+void SoundDeviceNetwork::readProcess(SINT framesPerBuffer) {
     if (!m_inputFifo || !m_pNetworkStream || !m_iNumInputChannels) {
         return;
     }
+    DEBUG_ASSERT(m_configFramesPerBuffer >= framesPerBuffer);
 
-    int inChunkSize = m_framesPerBuffer * m_iNumInputChannels;
+    int inChunkSize = framesPerBuffer * m_iNumInputChannels;
     int readAvailable = m_pNetworkStream->getReadExpected()
             * m_iNumInputChannels;
     int writeAvailable = m_inputFifo->writeAvailable();
@@ -220,15 +222,16 @@ void SoundDeviceNetwork::readProcess() {
         clearInputBuffer(inChunkSize - readCount, readCount);
     }
 
-    m_pSoundManager->pushInputBuffers(m_audioInputs, m_framesPerBuffer);
+    m_pSoundManager->pushInputBuffers(m_audioInputs, framesPerBuffer);
 }
 
-void SoundDeviceNetwork::writeProcess() {
-    if (!m_outputFifo || !m_pNetworkStream) {
+void SoundDeviceNetwork::writeProcess(SINT framesPerBuffer) {
+    if (!m_outputFifo || !m_pNetworkStream || !m_iNumOutputChannels) {
         return;
     }
+    DEBUG_ASSERT(m_configFramesPerBuffer >= framesPerBuffer);
 
-    int outChunkSize = m_framesPerBuffer * m_iNumOutputChannels;
+    int outChunkSize = framesPerBuffer * m_iNumOutputChannels;
     int writeAvailable = m_outputFifo->writeAvailable();
     int writeCount = outChunkSize;
     if (outChunkSize > writeAvailable) {
@@ -288,37 +291,51 @@ void SoundDeviceNetwork::workerWriteProcess(NetworkOutputStreamWorkerPtr pWorker
         int outChunkSize, int readAvailable,
         CSAMPLE* dataPtr1, ring_buffer_size_t size1,
         CSAMPLE* dataPtr2, ring_buffer_size_t size2) {
-    int writeExpected = static_cast<int>(pWorker->getStreamTimeFrames() - pWorker->framesWritten());
+    int writeExpectedFrames = static_cast<int>(
+            pWorker->getStreamTimeFrames() - pWorker->framesWritten());
 
-    int writeAvailable = writeExpected * m_iNumOutputChannels;
-    int copyCount = qMin(readAvailable, writeAvailable);
+    int writeExpected = writeExpectedFrames * m_iNumOutputChannels;
+
+    if (writeExpected <= 0) {
+        // Overflow
+        // kLogger.debug() << "workerWriteProcess: buffer full"
+        //                 << "outChunkSize" << outChunkSize
+        //                 << "readAvailable" << readAvailable
+        //                 << "writeExpected" << writeExpected << pWorker->getStreamTimeFrames();
+        // catch up by skipping chunk
+        m_pSoundManager->underflowHappened(25);
+    }
+    int copyCount = qMin(readAvailable, writeExpected);
 
     if (copyCount > 0) {
-        if (writeAvailable - copyCount > outChunkSize) {
+        if (writeExpected - copyCount > outChunkSize) {
             // Underflow
-            //kLogger.debug() << "workerWriteProcess: buffer empty";
+            // kLogger.debug() << "workerWriteProcess: buffer empty";
             // catch up by filling buffer until we are synced
-            workerWriteSilence(pWorker, writeAvailable - copyCount);
+            workerWriteSilence(pWorker, writeExpected - copyCount);
             m_pSoundManager->underflowHappened(24);
-        } else if (writeAvailable - copyCount > outChunkSize / 2) {
+        } else if (writeExpected - copyCount > outChunkSize / 2) {
             // try to keep PAs buffer filled up to 0.5 chunks
             if (pWorker->outputDrift()) {
                 // duplicate one frame
-                //kLogger.debug() << "workerWriteProcess() duplicate one frame"
-                //                << (float)writeAvailable / outChunkSize << (float)readAvailable / outChunkSize;
+                // kLogger.debug() << "workerWriteProcess() duplicate one frame"
+                //                 << (float)writeExpected / outChunkSize
+                //                 << (float)readAvailable / outChunkSize;
                 workerWrite(pWorker, dataPtr1, 1);
             } else {
                 pWorker->setOutputDrift(true);
             }
-        } else if (writeAvailable < outChunkSize / 2 ||
-                readAvailable > outChunkSize * 1.5
-           ) {
-            // We are not able to store at least the half of the new frames
-            // or we have a risk of an m_outputFifo overflow
+        } else if (writeExpected < outChunkSize / 2) {
+            // We will overshoot by more than a half of the new frames
             if (pWorker->outputDrift()) {
-                //kLogger.debug() << "SoundDeviceNetwork::workerWriteProcess() skip one frame"
-                //                << (float)writeAvailable / outChunkSize << (float)readAvailable / outChunkSize;
-                copyCount = qMin(readAvailable, copyCount + m_iNumOutputChannels);
+                // kLogger.debug() << "SoundDeviceNetwork::workerWriteProcess() "
+                //                    "skip one frame"
+                //                 << (float)writeAvailable / outChunkSize
+                //                 << (float)readAvailable / outChunkSize;
+                if (size1 >= m_iNumOutputChannels) {
+                    dataPtr1 += m_iNumOutputChannels;
+                    size1 -= m_iNumOutputChannels;
+                }
             } else {
                 pWorker->setOutputDrift(true);
             }
@@ -409,8 +426,12 @@ void SoundDeviceNetwork::workerWriteSilence(NetworkOutputStreamWorkerPtr pWorker
 }
 
 void SoundDeviceNetwork::callbackProcessClkRef() {
+    const SINT framesPerBuffer = m_configFramesPerBuffer;
+
     // This must be the very first call, to measure an exact value
-    updateCallbackEntryToDacTime();
+    // NOTE: For network streams the buffer size is always the configured buffer
+    //       size
+    updateCallbackEntryToDacTime(framesPerBuffer);
 
     Trace trace("SoundDeviceNetwork::callbackProcessClkRef %1",
                 m_deviceId.name);
@@ -440,7 +461,7 @@ void SoundDeviceNetwork::callbackProcessClkRef() {
 #if defined(__aarch64__)
         // Flush-to-zero on aarch64 is controlled by the Floating-point Control Register
         // Load the register into our variable.
-        int savedFPCR;
+        int64_t savedFPCR;
         asm volatile("mrs %[savedFPCR], FPCR"
                      : [ savedFPCR ] "=r"(savedFPCR));
 
@@ -462,33 +483,34 @@ void SoundDeviceNetwork::callbackProcessClkRef() {
         }
     }
 
-    m_pSoundManager->readProcess();
+    m_pSoundManager->readProcess(framesPerBuffer);
 
     {
         ScopedTimer t("SoundDevicePortAudio::callbackProcess prepare %1",
                 m_deviceId.name);
-        m_pSoundManager->onDeviceOutputCallback(m_framesPerBuffer);
+        m_pSoundManager->onDeviceOutputCallback(framesPerBuffer);
     }
 
-    m_pSoundManager->writeProcess();
+    m_pSoundManager->writeProcess(framesPerBuffer);
 
-    m_pSoundManager->processUnderflowHappened();
+    m_pSoundManager->processUnderflowHappened(framesPerBuffer);
 
-    updateAudioLatencyUsage();
+    updateAudioLatencyUsage(framesPerBuffer);
 }
 
-void SoundDeviceNetwork::updateCallbackEntryToDacTime() {
+void SoundDeviceNetwork::updateCallbackEntryToDacTime(SINT framesPerBuffer) {
     m_clkRefTimer.start();
     qint64 currentTime = m_pNetworkStream->getInputStreamTimeUs();
-    m_targetTime += m_audioBufferTime.toIntegerMicros();
+    // This deadline for the next buffer in microseconds since the Unix epoch
+    m_targetTime += static_cast<qint64>(framesPerBuffer / m_dSampleRate * 1000000);
     double callbackEntrytoDacSecs = (m_targetTime - currentTime) / 1000000.0;
     callbackEntrytoDacSecs = math_max(callbackEntrytoDacSecs, 0.0001);
     VisualPlayPosition::setCallbackEntryToDacSecs(callbackEntrytoDacSecs, m_clkRefTimer);
     //qDebug() << callbackEntrytoDacSecs << timeSinceLastCbSecs;
 }
 
-void SoundDeviceNetwork::updateAudioLatencyUsage() {
-    m_framesSinceAudioLatencyUsageUpdate += m_framesPerBuffer;
+void SoundDeviceNetwork::updateAudioLatencyUsage(SINT framesPerBuffer) {
+    m_framesSinceAudioLatencyUsageUpdate += framesPerBuffer;
     if (m_framesSinceAudioLatencyUsageUpdate
             > (m_dSampleRate / CPU_USAGE_UPDATE_RATE)) {
         double secInAudioCb = m_timeInAudioCallback.toDoubleSeconds();
