@@ -36,6 +36,7 @@
 #include "waveform/widgets/softwarewaveformwidget.h"
 #include "waveform/widgets/waveformwidgetabstract.h"
 #include "widget/wvumeter.h"
+#include "widget/wvumetergl.h"
 #include "widget/wwaveformviewer.h"
 
 namespace {
@@ -353,17 +354,29 @@ void WaveformWidgetFactory::destroyWidgets() {
     m_waveformWidgetHolders.clear();
 }
 
-void WaveformWidgetFactory::addTimerListener(WVuMeter* pWidget) {
+void WaveformWidgetFactory::addVuMeter(WVuMeter* pVuMeter) {
     // Do not hold the pointer to of timer listeners since they may be deleted.
     // We don't activate update() or repaint() directly so listener widgets
     // can decide whether to paint or not.
     connect(this,
             &WaveformWidgetFactory::waveformUpdateTick,
-            pWidget,
+            pVuMeter,
             &WVuMeter::maybeUpdate,
             Qt::DirectConnection);
 }
 
+void WaveformWidgetFactory::addVuMeter(WVuMeterGL* pVuMeter) {
+    // WVuMeterGLs to be rendered and swapped from the vsync thread
+    connect(this,
+            &WaveformWidgetFactory::renderVuMeters,
+            pVuMeter,
+            &WVuMeterGL::render);
+    connect(this,
+            &WaveformWidgetFactory::swapVuMeters,
+            pVuMeter,
+            &WVuMeterGL::swap);
+}
+
 void WaveformWidgetFactory::slotSkinLoaded() {
     setWidgetTypeFromConfig();
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0) && defined __WINDOWS__
@@ -673,6 +686,9 @@ void WaveformWidgetFactory::render() {
         // WSpinnys are also double-buffered QGLWidgets, like all the waveform
         // renderers. Render all the WSpinny widgets now.
         emit renderSpinnies(m_vsyncThread);
+        // Same for WVuMeterGL. Note that we are either using WVuMeter or WVuMeterGL.
+        // If we are using WVuMeter, this does nothing
+        emit renderVuMeters(m_vsyncThread);
 
         // Notify all other waveform-like widgets (e.g. WSpinny's) that they should
         // update.
@@ -729,6 +745,9 @@ void WaveformWidgetFactory::swap() {
         // WSpinnys are also double-buffered QGLWidgets, like all the waveform
         // renderers. Swap all the WSpinny widgets now.
         emit swapSpinnies();
+        // Same for WVuMeterGL. Note that we are either using WVuMeter or WVuMeterGL
+        // If we are using WVuMeter, this does nothing
+        emit swapVuMeters();
     }
     //qDebug() << "swap end" << m_vsyncThread->elapsed();
     m_vsyncThread->vsyncSlotFinished();
@@ -909,7 +928,7 @@ void WaveformWidgetFactory::evaluateWidgets() {
                 }
             }
         } else {
-            // No sufficiant GL supptor
+            // No sufficient GL supptor
             if (useOpenGles || useOpenGl || useOpenGLShaders) {
                 active = false;
             }
